OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Μετάβαση σε εξέλιξη. Παρακαλούμε περιμένετε μέχρι να ολοκληρωθεί η μετάβαση",
    "Migration started …" : "Η μετάβαση ξεκίνησε ...",
    "Saved" : "Αποθηκεύτηκαν",
    "Not saved" : "Δεν αποθηκεύτηκε",
    "Sending…" : "Γινεται αποστολή...",
    "Email sent" : "Το Email απεστάλη ",
    "Private" : "Ιδιωτικά",
    "Don't synchronize to servers" : "Να μη γίνει συγχρονισμός με τους διακομιστές.",
    "Trusted" : "Έμπιστος",
    "Only synchronize to trusted servers" : "Συγχρονισμός μόνο με έμπιστους διακομιστές.",
    "Public" : "Δημόσιο",
    "Synchronize to trusted servers and the global and public address book" : "Συγχρονισμός με αξιόπιστους διακομιστές του γενικού και δημόσιου βιβλίου διευθύνσεων",
    "Verify" : "Επαλήθευση",
    "Verifying …" : "Γίνεται επαλήθευση ...",
    "Unable to change password" : "Αδυναμία αλλαγής συνθηματικού",
    "Very weak password" : "Πολύ αδύναμο συνθηματικό",
    "Weak password" : "Αδύναμο συνθηματικό",
    "So-so password" : "Μέτριο συνθηματικό",
    "Good password" : "Καλό συνθηματικό",
    "Strong password" : "Δυνατό συνθηματικό",
    "An error occurred while changing your language. Please reload the page and try again." : "Σφάλμα κατά την αλλαγή γλώσσας. Παρακαλώ ανανεώστε την σελίδα και δοκιμάστε ξανά.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Σφάλμα κατά την αλλαγή τοποθεσίας. Παρακαλώ ανανεώστε την σελίδα και δοκιμάστε ξανά.",
    "Select a profile picture" : "Επιλογή εικόνας προφίλ",
    "Week starts on {fdow}" : "Η εβδομάδα ξεκινά την {fdow}",
    "Groups" : "Ομάδες",
    "Group list is empty" : "Η λίστα της ομάδας είναι κενή",
    "Unable to retrieve the group list" : "Αδύνατη η ανάκτηση λίστας της ομάδας",
    "{actor} added you to group {group}" : "{actor} σας πρόσθεσε στην ομάδα {group}",
    "You added {user} to group {group}" : "Προσθέσατε τον χρήστη {user} στην ομάδα {group}",
    "{actor} added {user} to group {group}" : "{actor} πρόσθεσε τον χρήστη {user} στην ομάδα {group}",
    "An administrator added you to group {group}" : "Ένας διαχειριστής σάς πρόσθεσε στην ομάδα {group}",
    "An administrator added {user} to group {group}" : "Ένας διαχειριστής πρόσθεσε τον χρήστη {user} στην ομάδα {group}",
    "{actor} removed you from group {group}" : "{actor} σάς αφαίρεσε από την ομάδα {group}",
    "You removed {user} from group {group}" : "Αφαιρέσατε τον χρήστη {user} από την ομάδα {group}",
    "{actor} removed {user} from group {group}" : "{actor} αφαίρεσε τον χρήστη {user} από την ομάδα {group}",
    "An administrator removed you from group {group}" : "Ένας διαχειριστής σάς αφαίρεσε από την ομάδα {group}",
    "An administrator removed {user} from group {group}" : "Ένας διαχειριστής αφαίρεσε τον χρήστη {user} από την ομάδα {group}",
    "Your <strong>group memberships</strong> were modified" : "Τροποποιήθηκαν οι <strong>ιδιότητες της ομάδας </strong>σας",
    "{actor} changed your password" : "{actor} το συθηματικό σας άλλαξε",
    "You changed your password" : "Αλλάξατε το συνθηματικό σας",
    "Your password was reset by an administrator" : "Έχει γίνει επαναφορά του συνθηματικού σας από τον διαχειριστή",
    "Your password was reset" : "Έγινε επαναφορά του κωδικού πρόσβασης",
    "{actor} changed your email address" : "{actor} άλλαξε τη διεύθυνσή του ηλεκτρονικού ταχυδρομείου σας",
    "You changed your email address" : "Έχετε αλλάξει τη διεύθυνση ηλεκτρονικού ταχυδρομείου σας",
    "Your email address was changed by an administrator" : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας άλλαξε από τον διαχειριστή",
    "You created app password \"{token}\"" : "Δημιουργήσατε κωδικό εφαρμογής \"{token}\"",
    "You deleted app password \"{token}\"" : "Διαγράψατε τον κωδικό εφαρμογής \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Μετονομάσατε τον κωδικό εφαρμογής \"{token}\" σε \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Επιτρέψατε την πρόσβαση του συστήματος στο αναγνωριστικό της εφαρμογής \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Ανακαλέσατε την πρόσβαση του συστήματος στο αναγνωριστικό της εφαρμογής \"{token}\"",
    "Security" : "Ασφάλεια",
    "You successfully logged in using two-factor authentication (%1$s)" : "Έχετε συνδεθεί επιτυχώς με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Μία προσπάθεια σύνδεσης με τη χρήση ελέγχου ταυτότητας δύο-παραγόντων απέτυχε (%1$s)",
    "Remote wipe was started on %1$s" : "Η απομακρυσμένη εκκαθάριση ξεκίνησε %1$s",
    "Remote wipe has finished on %1$s" : "Η απομακρυσμένη εκκαθάριση τελείωσε %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ο δικός σας <ισχυρός>κωδικός πρόσβασης</ισχυρός>ή<ισχυρός>αλληλογραφίας</ισχυρός>τροποποιήθηκε",
    "Couldn't remove app." : "Αδυναμία αφαίρεσης εφαρμογής.",
    "Couldn't update app." : "Αδυναμία ενημέρωσης εφαρμογής",
    "Wrong password" : "Λάθος κωδικός πρόσβασης",
    "No user supplied" : "Δεν εισήχθη χρήστης",
    "Authentication error" : "Σφάλμα πιστοποίησης",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Παρακαλώ παρέχετε έναν κωδικό ανάκτησης διαχειριστή, διαφορετικά όλα τα δεδομένα χρήστη θα χαθούν.",
    "Wrong admin recovery password. Please check the password and try again." : "Λάθος κωδικός ανάκτησης διαχειριστή. Παρακαλούμε ελέγξτε τον κωδικό και δοκιμάστε ξανά.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Το σύστημα δεν υποστηρίζει αλλαγή κωδικού, αλλά το κλειδί κρυπτογράφησης του χρήστη ενημερώθηκε επιτυχώς.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "εγκατάσταση και ενημέρωση εφαρμογών μέσω του καταστήματος εφαρμογών ή του ",
    "Federated Cloud Sharing" : "Διαμοιρασμός σε ομόσπονδα σύννεφα ",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "Το cURL χρησιμοποιεί μια παρωχημένη %1$s έκδοση (%2$s). Παρακαλούμε αναβαθμίστε το λειτουργικό σας σύστημα αλλιώς δυνατότητες όπως %3$s δεν θα δουλέψουν αξιόπιστα.",
    "Invalid SMTP password." : "Μη έγκυρο συνθηματικό SMTP.",
    "Email setting test" : "Δοκιμή ρυθμίσεων email",
    "Well done, %s!" : "Συγχαρητήρια, %s!",
    "If you received this email, the email configuration seems to be correct." : "Εάν λάβατε αυτό το μήνυμα ηλεκτρονικού ταχυδρομείου, ",
    "Email could not be sent. Check your mail server log" : "Το μήνυμα ηλεκτρονικού ταχυδρομείου δεν εστάλη. Ελέγξτε το αρχείο καταγραφής.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Παρουσιάστηκε σφάλμα κατά την αποστολή e-mail. Παρακαλούμε ελέγξτε τις ρυθμίσεις σας.(Error: %s)",
    "You need to set your user email before being able to send test emails." : "Πρέπει να ορίσετε το email του χρήστη πριν να είστε σε θέση να στείλετε δοκιμαστικά emails.",
    "Invalid mail address" : "Μη έγκυρη διεύθυνση Ηλ.Ταχυδρομείου.",
    "Settings saved" : "Οι ρυθμίσεις αποθηκεύτηκαν",
    "Unable to change full name" : "Δεν ήταν δυνατή η αλλαγή του πλήρους ονόματός σας",
    "Unable to change email address" : "Αδυναμία αλλαγής διεύθυνσης Ηλ.Ταχυδρομείου",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Για να επιβεβαιώσετε τον λογαριασμό σας στο Twitter, δημοσιεύστε την παρακάτω δημοσίευση στο Twitter (σιγουρευτείτε ότι την δημοσιεύετε χωρίς χαρακτήρες αλλαγής γραμμής)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Για να επιβεβαιώσουμε τον ιστότοπό σας, αποθηκεύστε το κάτωθι περιεχόμενο , στον κατάλογο '.well-known/CloudIdVerificationCode.txt' (παρακαλώ βεβαιωθείτε ότι ολόκληρο το κείμενο υπάρχει σε μια γραμμή):",
    "%1$s changed your password on %2$s." : "%1$sάλλαξε το συνθηματικό σε %2$s.",
    "Your password on %s was changed." : "Ο κωδικός πρόσβασης στο %s έχει αλλάξει.",
    "Your password on %s was reset by an administrator." : "Έχει γίνει επαναφορά του κωδικού πρόσβασης στο %s από τον διαχειριστή.",
    "Your password on %s was reset." : "Έχει γίνει επαναφορά του κωδικού πρόσβασης στο %s. ",
    "Password for %1$s changed on %2$s" : "Ο κωδικός πρόσβασης για το %1$s άλλαξε σε %2$s",
    "Password changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
    "If you did not request this, please contact an administrator." : "Εάν δεν το αιτηθήκατε, παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
    "Your email address on %s was changed." : "Η ηλεκτρονική σας διεύθυνση στο %s έχει αλλάξει.",
    "Your email address on %s was changed by an administrator." : "Η διεύθυνση ηλεκτρονικής αλληλογραφίας στο %s άλλαξε από τον διαχειριστή.",
    "Email address for %1$s changed on %2$s" : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου για το %1$s άλλαξε σε %2$s",
    "Email address changed for %s" : "Το συνθηματικό άλλαξε για τον %s",
    "The new email address is %s" : "Η νέα διεύθυνση ηλεκτρονικής αλληλογραφίας είναι %s",
    "Your %s account was created" : "Ο λογαριασμός %s δημιουργήθηκε",
    "Welcome aboard" : "Καλώς ήλθατε",
    "Welcome aboard %s" : "Καλώς ήλθατε %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Καλωσήρθατε στον λογαριασμό σας %s, μπορείτε να προσθέσετε, προστατεύσετε και διαμοιράσετε τα δεδομένα σας.",
    "Your username is: %s" : "Το όνομα χρήστη σας είναι: %s",
    "Set your password" : "Καθορισμός συνθηματικού",
    "Go to %s" : "Πηγαίνετε στο %s",
    "Install Client" : "Εγκατάσταση πελάτη",
    "Logged in user must be a subadmin" : "Ο συνδεδεμένος χρήστης πρέπει να είναι subadmin",
    "Apps" : "Εφαρμογές",
    "Settings" : "Ρυθμίσεις",
    "Personal" : "Προσωπικά",
    "Administration" : "Διαχείριση",
    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
    "Groupware" : "Ομαδικό",
    "Overview" : "Επισκόπηση",
    "Basic settings" : "Βασικές ρυθμίσεις",
    "Sharing" : "Διαμοιρασμός",
    "Personal info" : "Προσωπικές πληροφορίες",
    "Mobile & desktop" : "Κινητό & σταθερό",
    "Create" : "Δημιουργία",
    "Change" : "Αλλαγή",
    "Delete" : "Διαγραφή",
    "Reshare" : "Επαναδιαμοιρασμός",
    "Unlimited" : "Απεριόριστο",
    "Verifying" : "Γίνεται επαλήθευση",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Η παλιά διαμόρφωση κρυπτογράφησης από διακομισή σε διακομιστή είναι ενεργοποιημένη. Σας προτείνουμε να την απενεργοποιήσετε.",
    "Nextcloud settings" : "Ρυθμίσεις Nextcloud ",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Η πιστοποίηση δύο-παραγόντων μπορεί να επιβληθεί σε όλους τους χρήστες και σε ομάδες. Εάν δεν έχουν ρυθμίσει πάροχο πιστοποίησης δύο βημάτων, δεν θα μπορούν να συνδεθούν.",
    "Enforce two-factor authentication" : "Υποχρεωτική πιστοποίηση δύο-παραγόντων",
    "Limit to groups" : "Όριο στις ομάδες",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Η υποχρεωτική χρήση πιστοποίησης δύο-βημάτων μπορεί να ρυθμιστεί μόνο για ομάδες.",
    "Two-factor authentication is enforced for all members of the following groups." : "Η πιστοποίηση Δύο-παραγόντων έχει επιβληθεί για όλα τα μέλη της ακόλουθης ομάδας.",
    "Enforced groups" : "Επιβαλλόμενες ομάδες",
    "Two-factor authentication is not enforced for members of the following groups." : "Η πιστοποίηση Δύο-Παραγόντων δεν έχει επιβληθεί στα μέλη της ακόλουθης ομάδας.",
    "Excluded groups" : "Εξαιρέθηκαν οι ομάδες",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Όταν επιλέγονται / εξαιρούνται ομάδες, χρησιμοποιούν την ακόλουθη λογική για να προσδιορίσουν εάν ένας χρήστης έχει επιβάλλει 2FA: Εάν δεν έχουν επιλεγεί ομάδες, το 2FA είναι ενεργοποιημένο για όλους εκτός από τα μέλη των αποκλεισμένων ομάδων. Εάν επιλεγούν ομάδες, το 2FA είναι ενεργοποιημένο για όλα τα μέλη αυτών. Αν ένας χρήστης βρίσκεται σε μια επιλεγμένη και μια αποκλεισμένη ομάδα, η επιλογή έχει προτεραιότητα και επιβάλλεται 2FA.",
    "Save changes" : "Αποθήκευση αλλαγών",
    "All" : "Όλες",
    "Limit app usage to groups" : "Περιορίστε τη χρήση της εφαρμογής σε ομάδες",
    "No results" : "Κανένα αποτέλεσμα",
    "Update to {version}" : "Ενημέρωση στην έκδοση {version}",
    "Remove" : "Αφαίρεση",
    "Disable" : "Απενεργοποίηση",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει ελάχιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Αυτή η εφαρμογή δεν έχει μέγιστη έκδοση του Nextcloud ανατεθειμένη. Αυτό θα αποτελεί σφάλμα στο μέλλον.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Αυτή η εφαρμογή δεν μπορεί να εγκατασταθεί διότι δεν εκπληρώνονται οι ακόλουθες εξαρτήσεις:",
    "View in store" : "Προβολή στο κέντρο εφαρμογών",
    "Visit website" : "Επισκεφθείτε την ιστοσελίδα",
    "Report a bug" : "Αναφορά σφάλματος",
    "User documentation" : "Τεκμηρίωση Χρήστη",
    "Admin documentation" : "Τεκμηρίωση Διαχειριστή",
    "Developer documentation" : "Τεκμηρίωση προγραμματιστή",
    "This app is supported via your current Nextcloud subscription." : "Αυτή η εφαρμογή υποστηρίζεται μέσω της τρέχουσας συνδρομής σας στο Nextcloud.",
    "Supported" : "Υποστηρίζεται",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Οι επιλεγμένες εφαρμογές αναπτύσσονται από και εντός της κοινότητας. Προσφέρουν κεντρική λειτουργικότητα και είναι έτοιμες για χρήση.",
    "Featured" : "Προτεινόμενο",
    "Update to {update}" : "Ενημέρωση σε {update}",
    "Update all" : "Ενημέρωση όλων",
    "Results from other categories" : "Αποτελέσματα από άλλες κατηγορίες",
    "No apps found for your version" : "Δεν βρέθηκαν εφαρμογές για αυτή την έκδοση",
    "Disable all" : "Απενεργοποίηση όλων",
    "Enable all" : "Ενεργοποίηση όλων",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n εφαρμογή έχει διαθέσιμη αναβάθμιση","%n εφαρμογές έχουν διαθέσιμη αναβάθμιση"],
    "Marked for remote wipe" : "Επισημάνθηκε για απομακρυσμένη εκκαθάριση",
    "Device settings" : "Ρυθμίσεις συσκευής",
    "Allow filesystem access" : "Επιτρέπεται η πρόσβαση στο σύστημα αρχείων",
    "Rename" : "Μετονομασία",
    "Revoke" : "Ανάκληση",
    "Wipe device" : "Εκκαθάριση συσκευής",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Η κατάργηση αυτού του αναγνωριστικού ενδέχεται να αποτρέψει την εκκαθάριστη της συσκευής σας αν δεν έχει ξεκινήσει ακόμα.",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome για Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS app",
    "Nextcloud Android app" : "Nextcloud Android app",
    "Nextcloud Talk for iOS" : "Nextcloud Talk για iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk για Android",
    "Sync client - {os}" : "Συγχρονισμός πελατών - {os}",
    "This session" : "Αυτή η συνεδρία",
    "Device" : "Συσκευή",
    "Last activity" : "Τελευταία δραστηριότητα",
    "Devices & sessions" : "Συσκευές & συνδέσεις",
    "Web, desktop and mobile clients currently logged in to your account." : "Έχουν συνδεθεί στον λογαριασμό σας από περιηγητή ιστού, υπολογιστή και εφαρμογή τηλεφώνου.",
    "Do you really want to wipe your data from this device?" : "Θέλετε σίγουρα να διαγράψετε τα δεδομένα από την συσκεύη?",
    "Confirm wipe" : "Επιβεβαίωση εκκαθάρισης",
    "Error while creating device token" : "Σφάλμα κατά τη δημιουργία διακριτικού συσκευής",
    "Error while updating device token scope" : "Σφάλμα κατά την ενημέρωση του αναγνωριστικού συσκευής",
    "Error while updating device token name" : "Σφάλμα κατά την ενημέρωση του ονόματος αναγνωριστικού συσκευής",
    "Error while deleting the token" : "Σφάλμα κατά την διαγραφή του διακριτικού",
    "Error while wiping the device with the token" : "Σφάλμα κατά την εκκαθάριση συσκευής με το αναγνωριστικό",
    "App name" : "Όνομα εφαρμογής",
    "Create new app password" : "Δημιουργία νέου συνθηματικού εφαρμογής",
    "Use the credentials below to configure your app or device." : "Χρησιμοποιήστε τα παρακάτω διαπιστευτήρια για να ρυθμίσετε την εφαρμογή ή την συσκευή σας.",
    "For security reasons this password will only be shown once." : "Για λόγους ασφαλείας αυτό το συνθηματικό θα εμφανιστεί μόνο μια φορά.",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Done" : "Ολοκληρώθηκε",
    "Show QR code for mobile apps" : "Εμφάνιση κώδικα QR για τις εφαρμογές κινητού",
    "Copied!" : "Αντιγράφτηκε!",
    "Copy" : "Αντιγραφή",
    "Could not copy app password. Please copy it manually." : "Ο κωδικός εφαρμογής δεν μπορεί να αντιγραφεί. Παρακαλώ αντιγράψτε χειροκίνητα.",
    "You do not have permissions to see the details of this user" : "Δεν έχετε δικαιώματα να δείτε λεπτομέρειες του χρήστη",
    "Add new password" : "Προσθήκη νέου κωδικού πρόσβασης",
    "Add new email address" : "Προσθήκη νέας διεύθυνσης ηλ. αλληλογραφίας",
    "Add user in group" : "Προσθήκη χρήστη στην ομάδα",
    "Set user as admin for" : "Ορισμός χρήστη ως διαχειριστή για",
    "Select user quota" : "Επιλογή χωρητικότητας χρήστη",
    "No language set" : "Δεν ορίστηκε γλώσσα",
    "Delete user" : "Διαγραφή χρήστη",
    "Wipe all devices" : "Εκκαθάριση όλων των συσκευών",
    "Disable user" : "Απενεργοποίηση χρήστη",
    "Enable user" : "Ενεργοποίηση χρήστη",
    "Resend welcome email" : "Επαναποστολή αλληλογραφίας καλωσορίσματος",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Σε περίπτωση απώλειας συσκευής ή αποχώρησης απο τον οργανισμό, μπορεί να γίνει εκκαθάριση των δεδομένων του Nextcloud από όλες τις συσκευές σε σχέση με το {userid}. Λειτουργεί μόνο εάν η συσκευή είναι συνδεμένη στο ίντερνετ.",
    "Remote wipe of devices" : "Απομακρισμένη εκκαθάριση συσκευών",
    "Wipe {userid}'s devices" : "Εκκαθάριση συσκευών του {userid} ",
    "Cancel" : "Άκυρο",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Διαγραφή λογαριασμού του {userid} και όλων των προσωπικών αρχείων, δεδομένων εφαρμογών, κτλ.",
    "Account deletion" : "Διαγραφή λογαριασμού",
    "Delete {userid}'s account" : "Διαγραφή λογαριασμού του {userid}",
    "Welcome mail sent!" : "Απεστάλη το μήνυμα καλωσορίσματος!",
    "Edit User" : "Επεξεργασία Χρήστη",
    "Toggle user actions menu" : "Εναλλαγή μενού ρυθμίσεων χρήστη",
    "{size} used" : "{size} που χρησιμοποιείται",
    "Will be autogenerated" : "Θα δημιουργηθεί αυτόματα",
    "Display name" : "Εμφανιζόμενο όνομα",
    "Email" : "Ηλ.Ταχυδρομείο",
    "Default language" : "Προεπιλεγμένη γλώσσα",
    "Add a new user" : "Προσθήκη νέου χρήστη",
    "Close" : "Κλείσιμο",
    "Group admin for" : "Ομαδα διαχειριστή για",
    "Quota" : "Σύνολο Χώρου",
    "Language" : "Γλώσσα",
    "User backend" : "Σύστημα υποστήριξης χρήστη",
    "Storage location" : "Τοποθεσία αποθηκευτικού χώρου",
    "Last login" : "Τελευταία είσοδος",
    "No users in here" : "Δεν υπάρχουν χρήστες εδώ",
    "Default quota" : "Προεπιλέγμενη χωρητικότητα",
    "Common languages" : "Κοινές γλώσσες",
    "All languages" : "Όλες οι γλώσσες",
    "Password change is disabled because the master key is disabled" : "Η αλλαγή κωδικού είναι απενεργοποιημένη επειδή το κεντρικό κλειδί είναι απενεργοποιημένο",
    "Passwordless authentication requires a secure connection." : "Η σύνδεση χωρίς κωδικό πρόσβασης απαιτεί ασφαλή σύνδεση.",
    "Add WebAuthn device" : "Προσθήκη συσκευής WebAuthn ",
    "Please authorize your WebAuthn device." : "Παρακαλώ εξουσιοδοτήστε την συσκευή σας WebAuthn.",
    "Name your device" : "Ονομάστε την συσκευή σας",
    "Add" : "Προσθήκη",
    "Adding your device …" : "Πρόσθεση της συσκευής σας ...",
    "Server error while trying to add WebAuthn device" : "Σφάλμα διακομιστή κατά την προσθήκη συσκευής webAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Σφάλμα διακομιστή κατά την εγγραφή συσκευής WebAuthn",
    "Unnamed device" : "Ανώνυμη συσκευή",
    "Passwordless Authentication" : "Πιστοποίηση χωρίς Κωδικό Πρόσβασης",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Ρυθμίστε τον λογαριασμό σας για πιστοποίηση χωρίς κωδικό ακολουθώντας τα πρότυπα του FIDO2.",
    "No devices configured." : "Καμιά συσκευή δεν ρυθμίστηκε.",
    "The following devices are configured for your account:" : "Οι ακόλουθες συσκευές ρυθμίστηκαν για τον λογαριασμό σας:",
    "Your browser does not support WebAuthn." : "Ο περιηγητής σας δεν υποστηρίζει το WebAuthn.",
    "Your apps" : "Οι εφαρμογές σας",
    "Active apps" : "Ενεργές εφαρμογές",
    "Disabled apps" : "Απενεργοποιημένες εφαρμογές",
    "Updates" : "Ενημερώσεις",
    "App bundles" : "Πακέτα εφαρμογών",
    "Featured apps" : "Προτεινόμενες εφαρμογές",
    "{license}-licensed" : "{license}-αδειοδοτημένο",
    "Details" : "Λεπτομέρειες",
    "Changelog" : "Αρχείο καταγραφής αλλαγών",
    "by {author}\n{license}" : "από {author}\n{license}",
    "New user" : "Νέος χρήστης",
    "Enter group name" : "Εισάγετε όνομα ομάδας",
    "Add group" : "Προσθήκη ομάδας",
    "Everyone" : "Όλοι",
    "Admins" : "Διαχειριστές",
    "Disabled users" : "Απενεργοποιημένοι χρήστες",
    "Remove group" : "Αφαίρεση ομάδας",
    "Default quota:" : "Προεπιλεγμένο όριο:",
    "Select default quota" : "Επιλογή προεπιλεγμένης χωρητικότητας",
    "Show Languages" : "Εμφάνιση γλωσσών",
    "Show last login" : "Εμφάνιση τελευταιας σύνδεσης",
    "Show user backend" : "Εμφάνιση χρήστη συστήματος υποστήριξης",
    "Show storage path" : "Εμφάνιση διαδρομής αποθήκευσης",
    "Send email to new user" : "Αποστολή μηνύματος στο νέο χρήστη",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Πρόκειται να καταργήσετε την ομάδα {group}. Οι χρήστες ΔΕΝ θα διαγραφούν.",
    "Please confirm the group removal " : "παρακαλώ επιβεβαιώστε την κατάργηση της ομάδας",
    "Download and enable" : "Λήψη και ενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Enable untested app" : "Ενεργοποίηση δοκιμαστικής εφαρμογής",
    "The app will be downloaded from the app store" : "Θα γίνει λήψη της εφαρμογής από την αγορά εφαρμογών",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Η εφαρμογή δεν είναι συμβατή με την έκδοση Nextcloud σας. Εάν συνεχίσετε μπορείτε να εγκαταστήσετε την εφαρμογή. Η εφαρμογή ίσως να μην λειτουργεί σωστά.",
    "Never" : "Ποτέ",
    "An error occured during the request. Unable to proceed." : "Παρουσιάστηκε σφάλμα κατά την εκτέλεσητης του αιτήματος. Δεν είναι δυνατή η συνέχιση.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Η εφαρμογή έχει ενεργοποιηθεί αλλά χρειάζεται ενημέρωση. Θα μεταφερθείτε στη σελίδα ενημέρωσης σε 5 δευτερόλεπτα.",
    "App update" : "Ενημέρωση εφαρμογής",
    "Error: This app can not be enabled because it makes the server unstable" : "Σφάλμα: αυτή η εφαρμογή δεν μπορεί να ενεργοποιηθεί γιατί θα καταστήσει ασταθή τον διακομιστή.",
    "Administrator documentation" : "Τεκμηρίωση Διαχειριστή",
    "Documentation" : "Τεκμηρίωση",
    "Forum" : "Φόρουμ",
    "None" : "Τίποτα",
    "Login" : "Σύνδεση",
    "Plain" : "Απλό",
    "NT LAN Manager" : "Διαχειριστης NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Διακομιστής Email",
    "Open documentation" : "Άνοιγμα τεκμηρίωσης.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Είναι σημαντικό να ρυθμίσετε τον διακομιστή να μπορεί να στέλνει Ηλ.Ταχυδρομείο, όπως για επαναφορά κωδικού πρόσβασης και ειδοποιήσεις.",
    "Send mode" : "Κατάσταση αποστολής",
    "Encryption" : "Κρυπτογράφηση",
    "Sendmail mode" : "Κατάσταση αποστολής ηλ.μηνύματος",
    "From address" : "Από τη διεύθυνση",
    "mail" : "ταχυδρομείο",
    "Authentication method" : "Μέθοδος πιστοποίησης",
    "Authentication required" : "Απαιτείται πιστοποίηση",
    "Server address" : "Διεύθυνση διακομιστή",
    "Port" : "Θύρα",
    "Credentials" : "Πιστοποιητικά",
    "SMTP Username" : "Όνομα χρήστη SMTP",
    "SMTP Password" : "Συνθηματικό SMTP",
    "Save" : "Αποθήκευση",
    "Test email settings" : "Δοκιμή ρυθμίσεων email",
    "Send email" : "Αποστολή email",
    "Security & setup warnings" : "Προειδοποιήσεις ασφάλειας & ρυθμίσεων",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Είναι σημαντικό για την ασφάλεια και την απόδοση του συστήματός σας ότι όλα έχουν ρυθμιστεί σωστά. Για να σας βοηθήσουμε, κάνουμε μερικούς αυτόματους ελέγχους. Για περισσότερες πληροφορίες, ανατρέξτε στη σχετική τεκμηρίωση.",
    "All checks passed." : "Όλοι οι έλεγχοι επιτυχείς.",
    "There are some errors regarding your setup." : "Υπάρχουν μερικά σφάλματα σχετικά με τις ρυθμίσεις σας.",
    "There are some warnings regarding your setup." : "Υπάρχουν μερικές προειδοποιήσεις σχετικά με την εγκατάστασή σας.",
    "Checking for system and security issues." : "Έλεγχος για θέματα συστήματος και ασφάλειας.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Παρακαλώ ελέγξτε τις <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">οδηγίες εγκατάστασης ↗</a>, και ελέγξτε για σφάλματα ή προειδοποιήσεις στα <a href=\"%2$s\">αρχεία καταγραφής</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Ελέγξτε την ασφάλεια του Nextcloud σας μέσω <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">της σάρωσης ασφαλείας μας ↗</a>.",
    "Version" : "Έκδοση",
    "Two-Factor Authentication" : "Πιστοποίηση Δύο-Παραγόντων",
    "Server-side encryption" : "Κρυπτογράφηση από τον Διακομιστή",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Η κρυπτογράφηση από την πλευρά του διακομιστή καθιστά δυνατή την κρυπτογράφηση των αρχείων που μεταφορτώνονται σε αυτόν. Έρχεται όμως με περιορισμούς όπως την μείωση απόδοσης του, οπότε ενεργοποιήστε την μόνο εάν χρειάζεται.",
    "Enable server-side encryption" : "Ενεργοποίηση κρυπτογράφησης από το διακομιστή",
    "Please read carefully before activating server-side encryption: " : "Παρακαλούμε διαβάστε προσεκτικά πριν ενεργοποιήσετε την κρυπτογράφηση στο διακομιστή:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Μόλις ενεργοποιηθεί η κρυπτογράφηση, όλα τα αρχεία που θα μεταφορτωθούν από αυτό το σημείο και μετά θα κρυπτογραφηθούν στο διακομιστή. Η κρυπτογράφηση είναι δυνατόν να απενεργοποιηθεί αργότερα μόνο αν το ενεργό άρθρωμα κρυπτογράφησης υποστηρίζει αυτή τη λειτουργία και εκπληρούνται όλες οι προϋποθέσεις (πχ ορισμός κλειδιού ανάκτησης).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Η κρυπτογράφηση από μόνη της δεν εγγυάται την ασφάλεια του συστήματος. Για περισσότερες πληροφορίες σχετικά με τον τρόπο λειτουργίας της εφαρμογής κρυπτογράφησης και τις υποστηριζόμενες περιπτώσεις χρήσης, ανατρέξτε στην τεκμηρίωση.",
    "Be aware that encryption always increases the file size." : "Έχετε στο νου σας πως η κρυπτογράφηση πάντα αυξάνει το μέγεθος του αρχείου",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Είναι πάντοτε καλό να δημιουργείτε τακτικά αντίγραφα ασφαλείας των δεδομένων σας, στην περίπτωση της κρυπτογράφησης βεβαιωθείτε ότι έχετε λάβει αντίγραφο ασφαλείας των κλειδιών κρυπτογράφησης παράλληλα με τα δεδομένα σας.",
    "This is the final warning: Do you really want to enable encryption?" : "Αυτή είναι η τελευταία προειδοποίηση: Θέλετε πραγματικά να ενεργοποιήσετε την κρυπτογράφηση;",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Δεν έχει φορτωθεί μονάδα κρυπτογράφησης, παρακαλούμε φορτώστε μια μονάδα κρυπτογράφησης από το μενού εφαρμογών.",
    "Select default encryption module:" : "Επιλογή προεπιλεγμένης μονάδας κρυπτογράφησης:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Πρέπει να μεταφέρετε τα κλειδιά κρυπτογράφησής σας από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια. Παρακαλούμε ενεργοποιήστε την \"Προεπιλεγμένη Μονάδα Κρυπτογράφησης\" και εκτελέστε την εντολή 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Πρέπει να μεταφέρετε τα κλειδιά σας κρυπτογράφησης από την παλιά κρυπτογράφηση (ownCloud <= 8.0) στην καινούρια.",
    "Start migration" : "Έναρξη μετάβασης",
    "Background jobs" : "Εργασίες παρασκηνίου",
    "Last job execution ran %s. Something seems wrong." : "Η τελευταία εντολή έδειξε %s. Κάτι φαίνεται λάθος.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Ορισμένες εργασίες δεν εκτελέστηκαν από %s. Σκεφτείτε να αυξήσετε τη συχνότητα εκτέλεσης.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Ορισμένες εργασίες δεν εκτελέστηκαν από %s. Σκεφτείτε να μεταβείτε στο σύστημα cron.",
    "Last job ran %s." : "Η τελευταία εργασία %s.",
    "Background job didn’t run yet!" : "Η εργασία παρασκηνίου δεν εκτελέστηκε ακόμη!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Για βέλτιστη απόδοση είναι σημαντικό να ρυθμίσετε σωστά τις εργασίες παρασκηνίου. Για μεγαλύτερα συστήματα, η συνιστώμενη ρύθμιση είναι \"Cron\". Για περισσότερες πληροφορίες, ανατρέξτε στην τεκμηρίωση.",
    "Pick background job setting" : "Επιλέξτε τη ρύθμιση εργασίας φόντου",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "Το cron.php είναι καταχωρημένο σε μια υπηρεσία webcron ώστε να καλεί το cron.php κάθε 5 λεπτά μέσω HTTP.",
    "Use system cron service to call the cron.php file every 5 minutes." : "Χρησιμοποιήστε την cron υπηρεσία του συστήματος για να καλέσετε το cron.php αρχείο κάθε 5 λεπτά.",
    "The cron.php needs to be executed by the system user \"%s\"." : "Το cron.php πρέπει να εκτελεστεί από τον χρήστη του συστήματος \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Για να τρέξετε αυτό χρειάζεστε την επέκταση PHP POSIX. Δείτε {linkstart} PHP τεκμηρίωση {linked} για περισσότερες λεπτομέρειες.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ως διαχειριστής μπορείτε να ρυθμίσετε λεπτομερώς την συμπεριφορά διαμοιρασμού.\nΠαρακαλούμε ανατρέξτε στην τεκμηρίωση για περισσότερες πληροφορίες.",
    "Allow apps to use the Share API" : "Επιτρέπει την χρήση του API διαμοιρασμού σε εφαρμογές ",
    "Set default expiration date for shares" : "Ορισμός προεπιλεγμένης ημερομηνίας λήξης για τα κοινόχρηστα",
    "Expire after " : "Λήξη μετά από",
    "days" : "ημέρες",
    "Enforce expiration date" : "Επιβολή της ημερομηνίας λήξης",
    "Allow users to share via link" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μέσω συνδέσμου",
    "Allow public uploads" : "Επιτρέπεται το κοινόχρηστο ανέβασμα",
    "Always ask for a password" : "Ερώτηση συνθηματικού πάντα",
    "Enforce password protection" : "Επιβολή προστασίας με κωδικό",
    "Set default expiration date for link shares" : "Ορισμός προεπιλεγμένης ημερομηνίας λήξης για τους κοινόχρηστους συνδέσμους",
    "Allow resharing" : "Επιτρέπεται ο επαναδιαμοιρασμός",
    "Allow sharing with groups" : "Να επιτρέπεται ο διαμοιρασμός με ομάδες",
    "Restrict users to only share with users in their groups" : "Να επιτρέπεται σε χρήστες ο διαμοιρασμός μόνο με χρήστες που ανήκουν στις ομάδες τους",
    "Exclude groups from sharing" : "Εξαίρεση ομάδων από τον διαμοιρασμό",
    "These groups will still be able to receive shares, but not to initiate them." : "Αυτές οι ομάδες θα συνεχίσουν να λαμβάνουν διαμοιρασμούς, αλλά δεν θα είναι δυνατό να τους δημιουργήσουν.",
    "Restrict username autocompletion to users within the same groups" : "Περιορισμός της αυτόματης συμπλήρωσης του ονόματος χρήστη  σε χρήστες της ίδιας ομάδας",
    "This text will be shown on the public link upload page when the file list is hidden." : "Αυτό το κείμενο θα ",
    "Default share permissions" : "Προεπιλεγμένα δικαιώματα κοινόχρηστων",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Αναπτύχθηκε από τη {communityopen}Nextcloud κοινότητα{linkclose}, τον πηγαίο κώδικα {githubopen} {linkclose} αδειοδοτημένο υπό το {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Ακολουθήστε μας στην σελίδα μας στο facebook!",
    "Follow us on Twitter" : "Ακολουθήστε μας στο Twitter",
    "Follow us on Mastodon" : "Ακολουθήστε μας στο Mastodon",
    "Check out our blog" : "Επισκεφθείτε το ιστολόγιό μας!",
    "Subscribe to our newsletter" : "Εγγραφείτε στο ενημερωτικό δελτίο μας!",
    "Profile picture" : "Φωτογραφία προφίλ",
    "Upload new" : "Μεταφόρτωση νέου",
    "Select from Files" : "Επιλογή από τα Αρχεία",
    "Remove image" : "Αφαίρεση εικόνας",
    "png or jpg, max. 20 MB" : "png ή jpg, μεγ. 20 MB",
    "Picture provided by original account" : "Φωτογραφία που παρέχεται από τον πρωτότυπο λογαριασμό",
    "Choose as profile picture" : "Επιλέξτε εικόνα προφίλ",
    "You are a member of the following groups:" : "Είστε μέλος των ακόλουθων ομάδων:",
    "You are using <strong>%s</strong>" : "Χρησιμοποιείτε <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Χρησιμοποιείτε <strong>%1$s</strong> του <strong>%2$s</strong>(<strong>%3$s%%</strong>)",
    "Full name" : "Πλήρες όνομα",
    "No display name set" : "Δεν ορίστηκε όνομα",
    "Your email address" : "Η διεύθυνση ηλ. ταχυδρομείου σας",
    "No email address set" : "Δεν ορίστηκε διεύθυνση email",
    "For password reset and notifications" : "Για ανάκτηση συνθηματικού και ειδοποιήσεις",
    "Phone number" : "Αριθμός τηλεφώνου",
    "Your phone number" : "Ο αριθμός τηλεφώνου σας",
    "Address" : "Διεύθυνση",
    "Your postal address" : "Ο ταχυδρομικός σας κώδικας",
    "Website" : "Ιστοσελίδα",
    "It can take up to 24 hours before the account is displayed as verified." : "Η επαλήθευση του λογαριασμού μπορεί να διαρκέσει έως και 24 ώρες.",
    "Link https://…" : "Σύνδεσμος https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter handle @…",
    "Help translate" : "Βοηθήστε στη μετάφραση",
    "Locale" : "Τοπικό",
    "Current password" : "Τρέχων συνθηματικό",
    "New password" : "Νέο συνθηματικό",
    "Change password" : "Αλλαγή συνθηματικού",
    "Use a second factor besides your password to increase security for your account." : "Χρησιμοποιείστε έναν δεύτερο παράγοντα εκτός του κωδικού πρόσβασης για να αυξήσετε την ασφάλεια του λογαριαμού σας.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Προέκυψε σφάλμα. Παρακαλούμε μεταφορτώστε ένα πιστοποιητικό PEM κωδικοποιημένο κατά ASCII.",
    "Valid until {date}" : "Έγκυρο έως {date}",
    "Local" : "Τοπικά",
    "Only visible to local users" : "Εμφανές μόνο σε τοπικούς χρήστες",
    "Only visible to you" : "Εμφανές μόνο σε εσάς",
    "Contacts" : "Επαφές",
    "Visible to local users and to trusted servers" : "Προσθήκη στη λίστα των έμπιστων διακομιστών",
    "Will be synced to a global and public address book" : "Θα συγχρονιστεί με παγκόσμιο και δημόσιο βιβλίο διευθύνσεων",
    "by" : "από",
    "{counter} apps have an update available" : "{counter} εφαρμογές έχουν διαθέσιμη ενημέρωση",
    "SSL Root Certificates" : "Πιστοποιητικά SSL του Root",
    "Common Name" : "Κοινό Όνομα",
    "Valid until" : "Έγκυρο έως",
    "Issued By" : "Έκδόθηκε από",
    "Valid until %s" : "Έγκυρο έως %s",
    "Import root certificate" : "Εισαγωγή Πιστοποιητικού Root",
    "Execute one task with each page loaded" : "Εκτελεί μια διεργασία κάθε φορά που φορτώνεται μια σελίδα",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Να επιτρέπεται η χρήση αυτόματης συμπλήρωσης του ονόματος χρήστη στο πεδίο διαμοιρασμού. Αν η ρύθμιση αυτή είναι απενεργοποιημένη θα πρέπει να εισαχθεί το πλήρες όνομα χρήστη ή το email του. ",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Εμφάνιση κειμένου αποποίησης ευθυνών στη σελίδα δημοσίευσης συνδέσμων. (Εμφανίζεται μόνο όταν η λίστα αρχείων είναι κρυφή.)"
},
"nplurals=2; plural=(n != 1);");
